@@ -287,11 +287,11 @@ class LambdaToSsmstringparameterProps:
         :summary: The properties for the LambdaToSsmstringparameter class.
         '''
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = FunctionProps(**lambda_function_props)
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         if isinstance(string_parameter_props, dict):
-            string_parameter_props = StringParameterProps(**string_parameter_props)
+            string_parameter_props = aws_cdk.aws_ssm.StringParameterProps(**string_parameter_props)
         if isinstance(vpc_props, dict):
-            vpc_props = VpcProps(**vpc_props)
+            vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
         if __debug__:
             type_hints = typing.get_type_hints(LambdaToSsmstringparameterProps.__init__)
             check_type(argname="argument deploy_vpc", value=deploy_vpc, expected_type=type_hints["deploy_vpc"])
